---
title: '[2023년 07월] 서비스이용약관 개정 변경안내'
category: 공지사항
tags:
  - 공지사항
datetime: 2023-07-16T15:00:00.000Z
---

안녕하세요\~! 포트원 입니다.

항상 포트원을 이용해주시는 고객 여러분께 진심으로 감사드립니다.

2023년 07월 26일 아래와 같이 서비스 이용약관이 변경됨을 사전 안내 드립니다.

- 공고일 : 2023.07.17(월)
- 시행일 : 2023.07.26(수)

<Highlight text="변경 내용" />

<Accordion title="▶ 개인정보 위수탁에 관한 사항 > 개인정보항목" content="<>![](/uploads/포트원소식/개인정보 202307.png)</>" />
